<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT" sourcelanguage="en_GB">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Clicar para voltar para a Aplicação</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Itens</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Tentar novamente</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast no YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Quadro</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Paleta</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fundo</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Mudar Fundo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Subir na página</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Próxima Página</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Descer na página</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Gerir Documentos</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Navegar na Web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Traço Fino</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Traço Médio</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Traço Grosso</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Borracha</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Borracha Pequena</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Borracha Média</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Borracha Grande</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Cores</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Recuar</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Recarregar a página atual</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Página Inicial</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Carregar a Página Inicial</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Mostrar os Favoritos</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Adicionar aos Favoritos</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Mostrar o Quadro</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Apagar Conteúdo</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Mostrar Preferências</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Mostrar Biblioteca</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translatorcomment>&quot;Mostrar Ambiente de Trabalho&quot; (muito longo) - Mostrar a mesa</translatorcomment>
        <translation>Ver mesa</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Mostrar o ambiente de trabalho do Computador</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Aproximar</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Reduzir</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Afastar</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nova Pasta</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Criar uma Nova Pasta</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Novo Documento</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Criar um Novo Documento</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importar um Documento</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportar um Documento</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Abrir no Quadro</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Abrir Página no Quadro</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplicar o Conteúdo Selecionado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Apagar o Conteúdo Selecionado</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Adicionar ao Documento de Trabalho</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Adicionar o Conteúdo Selecionado ao Documento Aberto</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Adicionar Conteúdo ao Documento</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Mudar o Nome</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Mudar o Nome do Conteúdo</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Mostrar Ferramentas</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Écrans Múltiplos</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Formato Panorâmico (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Usar documento no Formato Panorâmico (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Formato Tradicional (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Usar documento no Formato Tradicional (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Tamanho Personalizado</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Usar documento no Tamanho Personalizado</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Parar de Carregar</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Parar de Carregar a Página Web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Modo &quot;Espera&quot;</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Colocar a Apresentaçãao em modo &quot;Espera&quot;</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado Virtual</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Mostrar o Teclado Virtual</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fundo Branco e Liso</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fundo Branco e Quadriculado</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fundo Preto e Liso</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fundo Preto e Quadriculado</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Gravar a Apresentação em Vídeo</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Iniciar a Gravação do Ecrã</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Apagar Itens</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Apagar Todos os Itens</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Apagar Anotações</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Apagar Todas as Anotações</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Limpar a Página</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Limpar Todos os Elementos</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Caneta</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Escrever</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>﻿Seletor</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Selecionar e Modificar Objetos</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Mão</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Desloca-se na página</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Apontador Laser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Apontador Laser Virtual</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Desenhar Linhas</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Escrever Texto</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar uma Parte do Ecrã</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Adicionar à Página Atual</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Adicionar Item à Página Atual</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Adicionar a uma Página Nova</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Adicionar Item a uma Página Nova</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Adicionar à Biblioteca</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Adicionar Item à Biblioteca</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Criar uma Nova Página</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nova Página</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplicar Página</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplicar a Página Atual</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importar Página</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importar uma Página Externa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pausar a Gravação do Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Configuração do Podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configuração da Gravação de Podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Captura de Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Captura de Conteúdo Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Captura de Web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Captura de Conteúdo Web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Captura Personalizada</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Captura da Janela</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Capturar uma Janela</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Conteúdo Web Embutido</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Capturar Conteúdo Web Embutido</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Mostrar no Ecrã</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Mostrar a Tela Principal no Ecrã</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Apagar todas as notas</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importar uma simulação eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Verificar Atualização</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Sair do OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Ocultar o OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Ocultar a Aplicação OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translatorcomment>Começar(?)</translatorcomment>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interagir com itens</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Apagar o fundo</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Remover o fundo</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Abrir Tutorial</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Abrir a página web de tutorial</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Autenticação Necessária</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticação do Proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Conetar ao Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de Utilizador:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Gravar &quot;Nome de Utilizador&quot; e &quot;Senha&quot; para futuras utilizações</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID do Elemento</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>O conteúdo não é suportado no formato de destino.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Remover Página</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Tem a certeza que quer remover 1 página do documento selecionado &apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Tamanho da Página</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Atualização disponível</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nova atualização disponível. Ir para a página web?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Nenhuma atualização disponível</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>A transferência de conteúdos falhou %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Transferência Completa</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tipo de ferramenta desconhecido %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tipo de conteúdo desconhecido %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Adicionar Item</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tudo Suportado (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Apagar a página %1 do documento</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Página %1 apagada</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Falha na operação de adição de ficheiro: erro na cópia do ficheiro</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Desagrupar</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Gravando documento...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Documento acaba de ser gravado...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Cores</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Erro ao Adicionar Imagem à Biblioteca</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Imagem capturada</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Propriedades da Cache</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar Parte do Ecrã</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Capturar Ecrã</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Mostrar Paleta</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Mostrar o Quadro num Ecrã Secundário</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Mostrar Ambiente de Trabalho num Ecrã Secundário</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Mostrar OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Nova Pasta</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Página %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Adicionar Pasta de Imagens</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Adicionar Imagens</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Adicionar Páginas de um Ficheiro</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>A Duplicar Documento %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Documento %1 Copiado</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Remover Página</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Remover Documento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Tem a certeza que quer remover o documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Vazar Lixo</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Tem a certeza que quer vazar a pasta Lixo? </translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">A vazar Lixo</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Pasta Lixo limpa</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Apagar Pasta</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Tem a certeza que quer apagar a pasta &apos;%1&apos; e todo o seu conteúdo?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Não há documentos selecionados!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Abrir Ficheiro Suportado</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>A importar ficheiro %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Falha ao importar ficheiro ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importar todas as Imagens de uma Pasta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vazio</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Abrir Documento</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Adicionar todas as imagens ao Documento</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Todas as Imagens (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>A seleção não contém ficheiros de Imagem!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Tem certeza que quer apagar %n página do documento selecionado &apos;%1&apos;?</numerusform>
            <numerusform>Tem certeza que quer apagar %n páginas do documento selecionado &apos;%1&apos;?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>O diretório não contém imagens</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documentos sem nome</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>O documento &apos;%1&apos; foi produzido com uma versão mais nova do OpenBoard (%2). Ao abri-lo, você poderá perder alguma informação. Gostaria de continuar?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Você tem certeza que deseja remover todos os documentos selecionados?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Remover múltiplos documentos</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>imagens</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>vídeos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objetos</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Todos os ficheiros suportados (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Ficheiro %1 gravado</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>A inserir página %1 de %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importação bem sucedida.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importação do ficheiro %1 bem sucedida.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>A importar o ficheiro %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Página %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Aceitar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Lixo</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 página copiada</numerusform>
            <numerusform>%1 páginas copiadas</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 página copiada</numerusform>
            <numerusform>%1 páginas copiadas</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">A copiar página %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (cópia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">A copiar página %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 página copiada</numerusform>
            <numerusform>%1 páginas copiadas</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>A descarregar ficheiro</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Página %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Página %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Surgiram alertas durante a exportação</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">A exportar documento...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished">Exportação falhou</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished">Exportação falhou: localização não gravável</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportar para IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportar como ficheiro IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Falha na Exportação.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportar como Ficheiro UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>A exportar %1 %2 de %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exportar para o formato OpenBoard</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Exportação falhou: localização não gravável</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Exportação falhou</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossível exportar para a localização selcionada. Você não possui as permissões necessárias para gravar o arquivo.</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como Ficheiro PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportar para PDF</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Exportação falhou: localização não gravável</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Exportação falhou</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossível exportar para a localização selecionada. Você não possui as permissões necessárias para gravar o arquivo.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como Ficheiro PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>A exportar página %1 de %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportar para PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportar para formato de Web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>A exportar documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportação bem sucedida.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Falha na exportação.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportar para Explorador Web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Adicionar à página</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Definir como fundo</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Adicionar à biblioteca</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informações do Objecto</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Partilhar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Voltar à pasta</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Criar uma nova pasta</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translatorcomment>&quot;Procurar ficheiro de Sistema&quot;(?)</translatorcomment>
        <translation>Voltar a procurar ficheiro de Sistema</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Imagem Importada</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Áudios</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animações</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Atividades Interativas</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formas</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Busca na web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Escrever um novo nome para o diretório</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>A carregar </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visível em Ecrã Expandido</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visível em Ecrã Expandido</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Ir para a Fonte do Conteúdo</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Definir como fundo</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Recurso de mídia não pode ser resolvido</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Formato de mídia não suportado</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Serviço de reprodução de mídia não encontrado</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Erro de mídia: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Introduzir o Texto Aqui&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Cor do Texto</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editável</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>A carregar ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Congelado</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformar em Ferramenta</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Formato de Ficheiro Frequente (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>A importar ficheiro %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Falha a importar ficheiro %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importação bem sucedida.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Falha na importação.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>A importar ficheiro %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Falha a importar ficheiro %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importação bem sucedida.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Formato da Imagem (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Falha na importação de PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>A importar a página %1 de %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Erro durante a publicação do vídeo na intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publicação na Intranet em progresso %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publicar</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduzir o Nome de Utilizador e Senha &quot;%1&quot; em %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Falha ao entrar no Proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Erros SSL:

%1

%2

Quer ignorar estes erros, deste servidor?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Documentos do Open-Sankore Detectado</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Mostrar este painel da próxima vez</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Você sempre poderá acessar o Importador de Documentos OpenBoard através do painel de Preferências na aba Sobre. Aviso, se você já importou seus dados do Open-Sankoré, você poderá perder seus atuais documentos do OpenBoard.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Prosseguir</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Documentos do Open-Sankoré estão presentes em seu computador. É possível importá-los para o OpenBoard pressionando o botão &quot;Prosseguir&quot; para lançar a aplicação de importação.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(cópia)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Repositório de Documentos perdido</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">Acesso ao repositório &apos;%1&apos; foi perdido. Infelizmente a aplicação deverá desligar para avitar a corrupção de dados. As últimas alterações também serão perdidas.</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francês</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francês (Suiço)</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Falha ao iniciar o codificador ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Nenhum codificador de Podcast disponível ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Parte %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>no seu ambiente de trabalho ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>na pasta %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast criado %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Erro de gravação do Podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Entrada de áudio padrão</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Sem gravação de áudio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publicar na Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publicar no Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versão: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>O marcador é sensível à pressão</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Iniciar sessão no Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nome de Utilizador:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Senha:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publicar documentos na web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Título:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descrição:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publicar</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Os meus filmes</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Visível na próxima vez</translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>A gerar pré-visualização de miniaturas ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 de miniaturas geradas ...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Página %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Cortina</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Régua</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Compasso</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Transferidor</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Esquadro</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Página completa</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Atualizador de documento</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> arquivos requerem uma atualização.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Localização da Cópia de Segurança:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Selecione uma pasta para a Cópia de Segurança</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Aguarde. O processo de importação vai começar em breve...</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Atualização de ficheiros bem sucedida!
Por favor, reinicie o aplicativo para aceder aos documentos atualizados.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Ocorreu um erro durante a atualização. Os ficheiros não foram afetados.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultados da actualização de ficheiros</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>A actualizar o ficheiro </translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar-me depois</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 pedido (método=%1, estado=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Erro de autenticação no YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Erro no envio do vídeo para o YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Envio para o YouTube em curso %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Automóveis</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Animais</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Desporto</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Viagens e Eventos</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Humor</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Pessoas e Blogues</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Notícias e Política</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Entretenimento</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Educação</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Guias e Estilo</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Sem fins lucrativos e Ativismo</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Ciência e Tecnologia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Gravar ficheiro</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download cancelado: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Erro a abrir o ficheiro gravado: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Erro ao gravar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erro na Ligação: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 de tempo restante</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 de %2 (%3/seg) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translatorcomment>Tamanho do ficheiro desconhecido</translatorcomment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Parado</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 ficheiro descarregado</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translatorcomment>Sempre &gt;= 2</translatorcomment>
        <translation>%1 ficheiros descarregados</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 item(s)</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Novo &amp;Separador</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Duplicar Separador</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fechar Separador</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Fechar os &amp;Outros Separadores</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Atualizar Separador</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Atualizar todos os Separadores</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Separadores recentemente fechados</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Sem Título)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Sem pesquisas recentes</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Pesquisas recentes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Limpar as pesquisas recentes</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Descarregar</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Adicionar ao documento atual</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Erro ao carregar a página: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Download de Documento PDF: você prefere baixar o arquivo PDF ou adicioná-lo ao atual documento OpenBoard?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir num Novo Separador</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast no Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palavras chave</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nome de utilizador do Youtube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Senha do Youtube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Clicando em &apos;Enviar&apos;, você certifica que possui todos os direitos sobre o conteúdo ou que está autorizado pelo proprietário a tornar o conteúdo disponível publicamente no YouTube, e que esta de acordo com os Termos de Serviço do YouTube localizado em&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Reestabelecer credenciais ao reiniciar</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Num fundo branco</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Num fundo preto</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidade</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Largura da linha</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Largo</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fino</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Caneta sensível à pressão</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Caixa de Diálogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Caixa de Diálogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Título</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Descrição</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Documentos OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versão : ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Configuração por defeito</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Exibir</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Mostrar a página num Browser externo</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Página de entrada:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Tamanho dos botões do teclado:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de ferramentas</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Posicionado no topo (recomendado para tablets)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Posicionado em baixo (recomendado para quadros brancos)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Mostrar o texto por debaixo dos botões</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Caneta</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenças</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Atualização de Software</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Verificar atualizações de software no arranque</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Écrans Múltiplos</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Mostrar o conteúdo interno da página web num ecrã ou projetor secundário</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translatorcomment>Trocar entre o ecrã de controlo e apresentação?</translatorcomment>
        <translation>Trocar entre o ecrã de controlo e visualização</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translatorcomment>&quot;Mode to start in:&quot;</translatorcomment>
        <translation>Modo iniciar:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Quadro</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy User:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Importador Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Verifique se os dados do Open-Sankoré poderão ser importados na inicialização</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Usar teclado do sistema (recomendado)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Tamanho da tecla do teclado virtual embarcado:</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Num fundo preto</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Opacidade</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Num fundo branco</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Capturar flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Selecionar o flash a capturar</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>Acerca:em branco</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nome da Aplicação</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Criar Aplicação</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
